==> RsFsw-5.20.1.tar.gz: RsFsw-5.20.1/RsFsw/Implementations/Applications/K30_NoiseFigure/System/Communicate/Rdevice/Generator/TypePy.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, name: str) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:TYPE \n
		Snippet: driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.typePy.set(name = '1') \n
		This command selects the type of external generator. This command is only valid if External Generator Control (R&S
		FSW-B10) is installed. \n
			:param name: Generator name as string value
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator:TYPE {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:TYPE \n
		Snippet: value: str = driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.typePy.get() \n
		This command selects the type of external generator. This command is only valid if External Generator Control (R&S
		FSW-B10) is installed. \n
			:return: name: Generator name as string value"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator:TYPE?')
		return trim_str_response(response)

==> RsFsw-6.0.0.tar.gz: RsFsw-6.0.0/RsFsw/Implementations/Applications/K30_NoiseFigure/System/Communicate/Rdevice/Generator/TypePy.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, name: str) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:TYPE \n
		Snippet: driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.typePy.set(name = 'abc') \n
		Selects the type of external generator. For a list of the available generator types, see the specifications document. Is
		only valid if External Generator Control (R&S FSW-B10) is installed. \n
			:param name: Generator name as string value
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator:TYPE {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:TYPE \n
		Snippet: value: str = driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.typePy.get() \n
		Selects the type of external generator. For a list of the available generator types, see the specifications document. Is
		only valid if External Generator Control (R&S FSW-B10) is installed. \n
			:return: name: Generator name as string value"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator:TYPE?')
		return trim_str_response(response)
